@@ -6,10 +6,10 @@ use warnings;
 
 BEGIN {
     delete $ENV{$_} for qw(http_proxy https_proxy);
-};
+}
 
-use JSON;
-use LWP::Simple qw( get );
+use App::ElasticSearch::Utilities qw(:all);
+use ElasticSearch;
 use IO::Socket::INET;
 use Getopt::Long;
 use Pod::Usage;
@@ -23,12 +23,11 @@ GetOptions(\%opt,
     'carbon-proto:s',
     'carbon-server:s',
     'carbon-port:i',
+    'with-indices',
     'host:s',
     'local',
     'help|h',
     'manual|m',
-    'verbose|v',
-    'debug|d',
 );
 
 #------------------------------------------------------------------------#
@@ -103,34 +102,60 @@ if( exists $cfg{'carbon-server'} and length $cfg{'carbon-server'} ) {
     die "unable to connect to carbon server: $!" unless defined $carbon_socket && $carbon_socket->connected;
 }
 
+#------------------------------------------------------------------------#
+# Connect to ElasticSearch
+my $HOST = exists $opt{local} && $opt{local} ? 'localhost:9200' : "$opt{host}:9200";
+my $ES = ElasticSearch->new(
+    transport  => 'http',
+    servers    => $HOST,
+    timeout    => 30,
+    no_refresh => 1,
+);
+#
 #------------------------------------------------------------------------#
 # Collect and Decode the Cluster Statistics
-my @stats = qw(indices os process jvm network transport http fs thread_pool);
-my $qs = join('&', map { "$_=true" } @stats );
-my $url = exists $opt{local} && $opt{local}
-        ? "http://localhost:9200/_cluster/nodes/_local/stats?$qs"
-        : "http://$opt{host}:9200/_cluster/nodes/stats?$qs";
-my $json = get($url);
-my $data = JSON->new->decode( $json );
-my $node_data = parse_stats( $data );
+my @metrics = ();
+my $stats = undef;
+eval {
+    $stats = $ES->nodes_stats( all => 1 );
+    debug_var({color=>'yellow'}, $stats);
+};
+if( my $err = $@ ) {
+    output({color=>'red'}, "Error retrieving nodes_stats(): $err");
+    exit 1;
+}
+push @metrics, @{ parse_nodes_stats($stats) };
+
+# Collect individual indexes names and their own statistics
+if( exists $cfg{'with-indices'} ) {
+    my $index_stats = undef;
+    eval {
+        $index_stats = $ES->index_stats(
+            index => '_all',
+            all   => 1,
+        );
+        debug_var({color=>'yellow'}, $index_stats);
+    };
+    push @metrics, @{ parse_index_stats( $index_stats ) };
+}
 
 #------------------------------------------------------------------------#
 # Send output to appropriate channels
-foreach my $stat ( @{ $node_data } ) {
+foreach my $stat ( @metrics ) {
     my $output = format_output( $stat );
     if( defined $carbon_socket && $carbon_socket->connected) {
         $carbon_socket->send( $output );
-        print STDERR $output if $cfg{verbose};
+        verbose($output);
     }
     else {
-        print $output;
+        output($output);
     }
 }
 
 
 #------------------------------------------------------------------------#
 # Generate Node Statistics Hash
-sub parse_stats {
+sub parse_nodes_stats {
     my $data = shift;
 
     my $node_id;
@@ -189,6 +214,11 @@ sub parse_stats {
         # Field Data
         "indices.fielddata.evictions $node->{indices}{fielddata}{evictions}",
         "indices.fielddata.size $node->{indices}{fielddata}{memory_size_in_bytes}",
+        # Filter Cache
+        "indices.filter.evictions $node->{indices}{filter_cache}{evictions}",
+        "indices.filter.size $node->{indices}{filter_cache}{memory_size_in_bytes}",
+        # ID Cache
+        "indices.id.size $node->{indices}{id_cache}{memory_size_in_bytes}",
         ;
 
     # Transport Details
@@ -254,6 +284,54 @@ sub parse_stats {
     return \@stats;
 }
 
+#------------------------------------------------------------------------#
+# Generate Individual Index Statistics Stats
+sub parse_index_stats{
+    my $data = shift;
+    my $index_name;
+    my @indices_stats;
+    foreach my $index (keys %{ $data->{indices} }) {
+	foreach my $group ("primaries", "total") {
+	    my $index_data = $data->{indices}{$index}{$group};
+
+	    push @indices_stats,
+    		# Basic Stats
+    		"individual_indices.$index.$group.docs.count $index_data->{docs}{count}",
+    		"individual_indices.$index.$group.docs.deleted $index_data->{docs}{deleted}",
+    		"individual_indices.$index.$group.store.size_in_bytes $index_data->{store}{size_in_bytes}",
+    		"individual_indices.$index.$group.store.throttle_time_in_millis $index_data->{store}{throttle_time_in_millis}",
+
+    		# Indexing
+    		"individual_indices.$index.$group.indexing.index_total $index_data->{indexing}{index_total}",
+    		"individual_indices.$index.$group.indexing.index_time_in_millis $index_data->{indexing}{index_time_in_millis}",
+    		"individual_indices.$index.$group.indexing.index_current $index_data->{indexing}{index_current}",
+    		"individual_indices.$index.$group.indexing.delete_total $index_data->{indexing}{delete_total}",
+    		"individual_indices.$index.$group.indexing.delete_time_in_millis $index_data->{indexing}{delete_time_in_millis}",
+    		"individual_indices.$index.$group.indexing.delete_current $index_data->{indexing}{delete_current}",
+
+    		# Get
+    		"individual_indices.$index.$group.get.total $index_data->{get}{total}",
+    		"individual_indices.$index.$group.get.time_in_millis $index_data->{get}{time_in_millis}",
+    		"individual_indices.$index.$group.get.exists_total $index_data->{get}{exists_total}",
+    		"individual_indices.$index.$group.get.exists_time_in_millis $index_data->{get}{exists_time_in_millis}",
+    		"individual_indices.$index.$group.get.missing_total $index_data->{get}{missing_total}",
+    		"individual_indices.$index.$group.get.missing_time_in_millis $index_data->{get}{missing_time_in_millis}",
+    		"individual_indices.$index.$group.get.current $index_data->{get}{current}",
+
+    		# Search
+    		"individual_indices.$index.$group.search.open_contexts $index_data->{search}{open_contexts}",
+    		"individual_indices.$index.$group.search.query_total $index_data->{search}{query_total}",
+    		"individual_indices.$index.$group.search.query_time_in_millis $index_data->{search}{query_time_in_millis}",
+    		"individual_indices.$index.$group.search.query_current $index_data->{search}{query_current}",
+    		"individual_indices.$index.$group.search.fetch_total $index_data->{search}{fetch_total}",
+    		"individual_indices.$index.$group.search.fetch_time_in_millis $index_data->{search}{fetch_time_in_millis}",
+    		"individual_indices.$index.$group.search.fetch_current $index_data->{search}{fetch_current}",
+		;
+	}
+    }
+    return \@indices_stats;
+}
+
 #------------------------------------------------------------------------#
 # Formatters
 sub format_output {
@@ -277,7 +355,7 @@ es-metrics-to-graphite.pl - Gather performance metrics from an ES node and send
 
 =head1 VERSION
 
-version 1.2
+version 1.3
 
 =head1 SYNOPSIS
 
@@ -295,6 +373,7 @@ Options:
     --carbon-port       Port for to use for Carbon (Default: 2003)
     --carbon-proto      Protocol for to use for Carbon (Default: tcp)
     --verbose           Send additional messages to STDERR
+    --with-indices      Also send individual index stats
 
 =head1 DESCRIPTION
 
@@ -346,6 +425,10 @@ and does not produce stats on STDOUT
 
 Use this port for the carbon server, useless without --carbon-server
 
+=item B<with-indices>
+
+Also grab data at the individual index level
+
 =item B<verbose>
 
 Verbose stats, to not interfere with cacti, output goes to STDERR
